@@ -2,7 +2,6 @@
 """
 
 # Standard library imports
-from typing import Union
 
 # Third party imports
 
@@ -15,9 +14,11 @@ def GET_MULTOS_DATA(hcard, protocol: Protocol) -> MultosData:
     r, error = send_apdu(hcard, protocol, _GET_MULTOS_DATA())
 
     if error is not None:
-        return None, error
-    elif r.SW12() != '9000':
-        return None, F"Response bytes to GET MULTOS DATA is not 9000 (SW12 = {r.SW12()})"
+        return None, F"Error getting the MULTOS data ({error})"
+
+    elif sw12 := r.SW12() != '9000':
+        return None, F"Error getting the MULTOS data (SW12 = {sw12})"
+
     else:
         multos_data = MultosData(r.data())
         return multos_data, None
